@@ -1,6 +1,7 @@
 import json
+from io import BytesIO
 from pathlib import Path
-from typing import List
+from typing import IO, Any, List, Union
 
 from agno.document.base import Document
 from agno.document.reader.base import Reader
@@ -12,14 +13,23 @@ class JSONReader(Reader):
 
     chunk: bool = False
 
-    def read(self, path: Path) -> List[Document]:
-        if not path.exists():
-            raise FileNotFoundError(f"Could not find file: {path}")
-
+    def read(self, path: Union[Path, IO[Any]]) -> List[Document]:
         try:
-            logger.info(f"Reading: {path}")
-            json_name = path.name.split(".")[0]
-            json_contents = json.loads(path.read_text("utf-8"))
+            if isinstance(path, Path):
+                if not path.exists():
+                    raise FileNotFoundError(f"Could not find file: {path}")
+                logger.info(f"Reading: {path}")
+                json_name = path.name.split(".")[0]
+                json_contents = json.loads(path.read_text("utf-8"))
+
+            elif isinstance(path, BytesIO):
+                logger.info(f"Reading uploaded file: {path.name}")
+                json_name = path.name.split(".")[0]
+                path.seek(0)
+                json_contents = json.load(path)
+
+            else:
+                raise ValueError("Unsupported file type. Must be Path or BytesIO.")
 
             if isinstance(json_contents, dict):
                 json_contents = [json_contents]
