@@ -11,7 +11,7 @@ from agno.models.base import Model
 from agno.models.message import Message
 from agno.models.response import ModelResponse
 from agno.utils.log import logger
-from agno.utils.openai import add_audio_to_message, add_images_to_message
+from agno.utils.openai import images_to_message
 
 try:
     from azure.ai.inference import ChatCompletionsClient
@@ -32,16 +32,9 @@ except ImportError:
     )
 
 
-@dataclass
-class AzureAIFoundryResponseUsage:
-    input_tokens: int = 0
-    output_tokens: int = 0
-    total_tokens: int = 0
-
-
 def _format_message(message: Message) -> Dict[str, Any]:
     """
-    Format a message into the format expected by Azure AI.
+    Format a message into the format expected by OpenAI.
 
     Args:
         message (Message): The message to format.
@@ -49,14 +42,29 @@ def _format_message(message: Message) -> Dict[str, Any]:
     Returns:
         Dict[str, Any]: The formatted message.
     """
+    message_dict: Dict[str, Any] = {
+        "role": message.role,
+        "content": message.content,
+        "name": message.name,
+        "tool_call_id": message.tool_call_id,
+        "tool_calls": message.tool_calls,
+    }
+    message_dict = {k: v for k, v in message_dict.items() if v is not None}
 
-    if message.images is not None:
-        message = add_images_to_message(message=message, images=message.images)
+    if message.images is not None and len(message.images) > 0:
+        # Ignore non-string message content
+        # because we assume that the images/audio are already added to the message
+        if isinstance(message.content, str):
+            message_dict["content"] = [{"type": "text", "text": message.content}]
+            message_dict["content"].extend(images_to_message(images=message.images))
 
     if message.audio is not None:
-        message = add_audio_to_message(message=message, audio=message.audio)
+        logger.warning("Audio input is currently unsupported.")
 
-    return message.serialize_for_model()
+    if message.videos is not None:
+        logger.warning("Video input is currently unsupported.")
+
+    return message_dict
 
 
 @dataclass
@@ -241,7 +249,7 @@ class AzureAIFoundry(Model):
         try:
             async with self.get_async_client() as client:
                 return await client.complete(
-                    messages=[m.serialize_for_model() for m in messages],
+                    messages=[_format_message(m) for m in messages],
                     **self._get_request_kwargs(),
                 )
         except HttpResponseError as e:
@@ -295,7 +303,7 @@ class AzureAIFoundry(Model):
         try:
             async with self.get_async_client() as client:
                 stream = await client.complete(
-                    messages=[m.serialize_for_model() for m in messages],
+                    messages=[_format_message(m) for m in messages],
                     stream=True,
                     **self._get_request_kwargs(),
                 )
@@ -354,11 +362,11 @@ class AzureAIFoundry(Model):
 
             # Add usage metrics if present
             if response.usage is not None:
-                model_response.response_usage = AzureAIFoundryResponseUsage(
-                    input_tokens=response.usage.prompt_tokens or 0,
-                    output_tokens=response.usage.completion_tokens or 0,
-                    total_tokens=response.usage.total_tokens or 0,
-                )
+                model_response.response_usage = {
+                    "input_tokens": response.usage.prompt_tokens or 0,
+                    "output_tokens": response.usage.completion_tokens or 0,
+                    "total_tokens": response.usage.total_tokens or 0,
+                }
 
         except Exception as e:
             logger.error(f"Error parsing Azure AI response: {e}")
